.. rst-class:: detail

WaitTime
===================

.. currentmodule:: compas_rrc

.. autoclass:: WaitTime

    
    
    .. rubric:: Methods

    .. autosummary::
        :toctree:

    
        ~WaitTime.__init__
        ~WaitTime.from_msg
    
    